require 'uu/applog/application_log/time_conversions'
require 'uu/os/rest/dto'

module UU
  module AppLog
    module ApplicationLog

      # DTO containing attributes of a new application log record.
      class ApplicationLogAddRecord < UU::OS::REST::DTO
        include TimeConversions

        # Time of the application log record creation (on the API consumer side). Mandatory attribute.
        # @param [String, DateTime, Time]
        # @return [String]
        attr_accessor :creation_time

        # Code of logger.
        # @param [String]
        # @return [String]
        attr_accessor :logger_code # TODO Describe what is a logger (briefly)

        # Severity of the application log record (value from {UU::AppLog::ApplicationLog::Severity}). Mandatory attribute.
        # @param [String]
        # @return [String]
        attr_accessor :severity

        # Identifier of the thread in which the application log record was created.
        # @param [String]
        # @return [String]
        attr_accessor :thread_id

        # Name of the thread in which the application log record was created.
        # @param [String]
        # @return [String]
        attr_accessor :thread_name

        # Message describing what happened.
        # @param [String]
        # @return [String]
        attr_accessor :message

        # Exception that occurred.
        # @param [String]
        # @return [String]
        attr_accessor :exception

        # Identifier of node (i.e. computer) on which the record was created.
        # @param [String]
        # @return [String]
        attr_accessor :node_id

        # IP address of node (i.e. computer) on which the record was created.
        # @param [String]
        # @return [String]
        attr_accessor :node_ip

        # Mapped diagnostic context. A structure containing key-value pairs with
        # optional information useful to troubleshoot the application.
        # @param [Hash]
        # @return [Hash]
        attr_accessor :mdc # TODO Review the doc comment text

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = to_iso8601(val)
        end

        def logger_code
          attributes[:loggerCode]
        end

        def logger_code=(val)
          attributes[:loggerCode] = val
        end

        def severity
          attributes[:severity]
        end

        def severity=(val)
          attributes[:severity] = val
        end

        def thread_id
          attributes[:threadID]
        end

        def thread_id=(val)
          attributes[:threadID] = val
        end

        def thread_name
          attributes[:threadName]
        end

        def thread_name=(val)
          attributes[:threadName] = val
        end

        def message
          attributes[:message]
        end

        def message=(val)
          attributes[:message] = val
        end

        def exception
          attributes[:exception]
        end

        def exception=(val)
          attributes[:exception] = val
        end

        def node_id
          attributes[:nodeID]
        end

        def node_id=(val)
          attributes[:nodeID] = val
        end

        def node_ip
          attributes[:nodeIP]
        end

        def node_ip=(val)
          attributes[:nodeIP] = val
        end

        def mdc
          attributes[:mdc]
        end

        def mdc=(val)
          attributes[:mdc] = val
        end

      end
    end
  end
end

